# pytonik

[![Build Status](https://img.shields.io/pypi/v/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Downloads](https://pepy.tech/badge/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Wheel](https://img.shields.io/pypi/wheel/pytonik.svg)](https://pypi.python.org/pypi/pytonik)
[![Python Version](https://img.shields.io/pypi/pyversions/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Buy Beer](https://img.shields.io/beerpay/pytonik/pytonik?style=flat-square)](https://beerpay.io/pytonik/pytonik)
[![Donate](http://img.shields.io/liberapay/receives/pytonik.svg?logo=liberapay)](https://liberapay.com/pytonik/donate)
[![License](https://img.shields.io/pypi/l/pytonik)](https://pypi.python.org/pypi/pytonik)
[![Donate](https://img.shields.io/badge/donate-KoFi-blue.svg)](https://ko-fi.com/pytonik)
[![Gitter](https://badges.gitter.im/pytonik-mvc/community.svg)](https://gitter.im/pytonik-mvc/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![Docs](https://img.shields.io/readthedocs/pytonik)](https://pytonik.readthedocs.io/en/latest)
[![lint_python](https://github.com/pytonik/pytonik/workflows/lint_python/badge.svg)](https://github.com/pytonik/pytonik/actions)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-green.svg)](https://github.com/pytonik/pytonik/blob/master/CONTRIBUTING.md)
![pytonik](https://github.com/pytonik/pytonik/workflows/pytonik/badge.svg)

<p align="center">
	<img  height="150" src="http://betacodings.com/public/pytonik_logo_color.png">
</p>

> Pytonik is a python framework built to enhance fast and easy web development, helping web developers build more apps with fewer codes.
> The framework uses an Expressive Architectural Pattern, structured on a Model-View-Controller (MVC), and bundles of components to reuse while deploying the framework.

[![Made with python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://pypi.python.org/pypi/pytonik)

## How to setup

Pytonik provides an inbuilt server for deployment and can as well be run on, WAMP, XAMPP, LAMP or MAMP, using CGI.

To Create Pytonik Project Folder

```
$ pytonik-start
```

To Run Pytonik Server

```
$ pytonik-server
```

To Install Project Requirements from `requirements.txt` file.

```
$ pytonik-install
```

To Read Pytonik Docs

```
$ pytonik-docs
```

## 🤝 Contributing

Contributions, issues and feature requests are welcome!

Feel free to check the [issues page](https://github.com/pytonik/pytonik/issues).

For guidance on setting up a development environment and how to make a contribution to Pytonik, see the [contributing guidelines.](https://github.com/pytonik/pytonik/blob/master/CONTRIBUTING.md)

## Documentation on how to?

- [Getting Started](https://pytonik.readthedocs.io/en/latest)

## Assistance

Having issue using or implementing modules and functions, upload your pytonik project on github, open an issues. our contributors and maintainers will look into it.

## Show your support

Give a ⭐️ if you like this project!

Support Pytonik and the libraries it uses. In order to grow the community of contributors and users, and allow the maintainers to devote more time to the projects, [please donate today.](https://liberapay.com/pytonik/)

## Contact

**Name:** Pytonik MVC

**Email:** dev@pytonik.com
